pygeai.tests.snippets.extras package
====================================

Submodules
----------

pygeai.tests.snippets.extras.igor module
----------------------------------------

.. automodule:: pygeai.tests.snippets.extras.igor
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.extras.igor\_2 module
-------------------------------------------

.. automodule:: pygeai.tests.snippets.extras.igor_2
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.extras.igor\_test module
----------------------------------------------

.. automodule:: pygeai.tests.snippets.extras.igor_test
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.extras
   :members:
   :show-inheritance:
   :undoc-members:
